@@ -2,12 +2,13 @@
 import logging
 import os
 
-from pls.args.parser import parser
 from pls.config import constants, icons, prefs, specs
 from pls.config.files import find_configs
 from pls.data.utils import internal_yml_path
 from pls.globals import args, state
 from pls.log.config import configure_log_level
+from pls.parser.parser import parser
+from pls.parser.validation import validate_args
 
 
 logger = logging.getLogger(__name__)
@@ -26,15 +27,15 @@ def init(argv=None):
     cli_prefs = parser.parse_args(argv)
     logger.debug(f"CLI arguments: {cli_prefs}")
 
-    args.args.directory = cli_prefs.directory
+    args.args.node = cli_prefs.node
 
     state.state = state_obj = state.State()
 
     state_obj.setup_home()
     state_obj.setup_user_groups()
-    state_obj.setup_git(cli_prefs.directory)
+    state_obj.setup_git(cli_prefs.node)
 
-    conf_files = find_configs(cli_prefs.directory)
+    conf_files = find_configs(cli_prefs.node)
     logger.debug(f"Config files read: {conf_files}")
 
     logger.info("Reading config files")
@@ -48,6 +49,7 @@ def init(argv=None):
 
     args.args.update(prefs.prefs)
     args.args.update(cli_prefs)
+    validate_args(args.args)
 
     logger.info("Reading icons")
     icons.nerd_icons, icons.emoji_icons = icons.get_icons(
@@ -94,7 +96,8 @@ def main() -> None:
     init(None)  # ``None`` makes ``argparse`` read real CLI args from ``sys.argv``
 
     from pls.fs.list import read_input
-    from pls.output.table import write_output
+    from pls.output.columns import ColumnsPrinter
+    from pls.output.table import TablePrinter
 
     node_map, node_list = read_input()
 
@@ -111,10 +114,16 @@ def main() -> None:
                 continue
             node.set_sub_pre_shapes()
 
-    write_output(node_list)
+    PrinterClass = ColumnsPrinter if args.args.multi_cols else TablePrinter
+    printer = PrinterClass(node_list)
+    printer.print()
 
 
 def dev() -> None:
     os.environ.setdefault("PLS_LOG_LEVEL", "DEBUG")  # Show detailed logs
 
     main()
+
+
+if __name__ == "__main__":
+    main()
